{% extends "admin/change_list.html" %}

{% load admin_list dblog_admin %}

{% block extrastyle %}
	{{ block.super }}
	{% include "admin/djangodblog/partials/change_list_styles.html" %}
{% endblock %}

{% block result_list %}
	{% if action_form and actions_on_top %}{% admin_actions %}{% endif %}
	{% result_list cl %}
	{% if action_form and actions_on_bottom %}{% admin_actions %}{% endif %}
{% endblock %}
